@@ -9,9 +9,11 @@
 #' @return [\code{list}].
 #' @export
 feature_chull = function(x) {
-	coords = x$coords
-  hull = chull(coords[, 1], coords[, 2])
-  area = areapl(coords[hull, ])
-  list(chull_area = area,
-       chull_points_on_hull = length(hull) / nrow(coords))
+    coords = x$coords
+    hull = chull(coords[, 1], coords[, 2])
+    area = areapl(coords[hull, ])
+    list(
+        chull_area = area,
+	   chull_points_on_hull = length(hull) / nrow(coords)
+    )
 }
