@@ -7,20 +7,20 @@
 #'   rows denote cities.
 #' @return [\code{matrix}] for \code{rescale_coords} and \code{tsp_instance} for \code{rescale_instance}.
 #'   Numeric matrix of scaled city coordinates.
-#' @export 
+#' @export
 rescale_instance = function(x) {
-  checkArg(x, "tsp_instance")
-  x$coords = rescale_coords(x$coords)
-	x$dists = as.matrix(dist(x$coords))
-  return(x)
+    assertClass(x, "tsp_instance")
+    x$coords = rescale_coords(x$coords)
+    x$dists = as.matrix(dist(x$coords))
+    return(x)
 }
 
-#' @export 
+#' @export
 #' @rdname rescale_instance
 rescale_coords = function(coords) {
-  min = apply(coords, 2, min)
-  max = apply(coords, 2, max)
-  t((t(coords) - min) / (max - min))
+    min = apply(coords, 2, min)
+    max = apply(coords, 2, max)
+    t((t(coords) - min) / (max - min))
 }
 
 
